@@ -4,10 +4,10 @@ function _aws_cdk_aws_elasticloadbalancingv2_targets_AlbTarget(p) {
 }
 function _aws_cdk_aws_elasticloadbalancingv2_targets_AlbArnTarget(p) {
 }
-function _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget(p) {
-}
 function _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceIdTarget(p) {
 }
+function _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget(p) {
+}
 function _aws_cdk_aws_elasticloadbalancingv2_targets_LambdaTarget(p) {
 }
 function print(name, deprecationMessage) {
@@ -25,5 +25,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbArnTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceIdTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_LambdaTarget };
+module.exports = { print, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbArnTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceIdTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_LambdaTarget };
 module.exports.DeprecationError = DeprecationError;
